function Y = tssinh(T,alpha,t0)

%TSSINH Timescale Hyperbolic Sine
% TSSINH(T,alpha,[t0]) is implemented using the form specified by
% Definition 3.17 of the Bohner-Peterson book. This function returns purely
% real results.
%
%   Brian Ballard, Bunmi Otegbade   08/05/05

type = size(T);

if (nargin < 2)
    error('At least two arguments required')
elseif (nargin > 3)
    error('Too many arguments')
end

% CASE: Only two input arguments
if(nargin == 2)

    % Checking if T is a valid timescale 
    if(~isa(T,'timescale'))
        error('First argument must be a timescale object');
    end

    % Checking if alpha is numeric
    if(~isnumeric(alpha))
        error('Second argument must be a number');
    end

    % Get the value of t0 from the timescale
    if (type(1)==0)
        error('Cannot compute SINH of an empty interval and only last interval can be empty.')
    else
        t0 = T(1);
    end
        
% CASE: Three input arguments
elseif(nargin == 3)

    if(~isa(T,'timescale'))
        error('First argument must be a timescale object');
    end

    if(~isnumeric(alpha))
        error('Second argument must be a number');
    end

    if(~isnumeric(t0))
        error('The initial condition must be a number');
    end

end

% Actual Calculations

Q = ( (tsexp(T,alpha,t0)) + (tsexp(T,(-alpha),t0)) ) / 2;
Y = real(Q);